#include "config_common.h"

#define USER_DATA_DIR "~/Library/Application Support/Armagetron Advanced Dedicated"
#define DEDICATED 1
#define KRAWALL_SERVER 1
#define HAVE_LIBZTHREAD 1
